import { HttpErrorResponse } from '@angular/common/http';
import { MatDialog } from '@angular/material/dialog';
import { MatSnackBar } from '@angular/material/snack-bar';
import { RootInjectorGuard } from './baseTypes';
import { MessageContentType } from './types';
import * as i0 from "@angular/core";
/**
 * Similar to JavaScript's alert() function, to display message in a dialog with LogDialogComponent,
 * or optionally a snackbar if message content type is text.
 * The mesage could be of type info, error, warn and success and response.
 * Browser console also wirte a copy of the message. The snackBar parameter is effective only when contentType is text.
 * When contentType is html, you MUST make sure the HTML content won't be harming the health of DOM managed by Angular.
 * For example, a href link without _blank, and malicious codes may damage Angular rendering.
 */
export declare class AlertService extends RootInjectorGuard {
    private snackBarService;
    private dialog;
    private subject;
    private initOnceSubscription;
    constructor(snackBarService: MatSnackBar, dialog: MatDialog);
    /**
     * Initiate the listening of SubjectMessage. Then redirect the message to either snackbar or dialog.
     * This should be called only once in the startup component like the app component.
     */
    initOnce(): void;
    /**
     * Display success message.
     * @param message
     * @param snackBar If not defined and message length is less than 50 and contentType is text, snackBar will be used.
     * @param subtitle
     * @param contentType
     */
    success(message: string, snackBar?: boolean, subtitle?: string, contentType?: MessageContentType): void;
    /**
     * Display info message.
     * @param message
     * @param snackBar
     * @param subtitle
     * @param contentType
     */
    info(message: string, snackBar?: boolean, subtitle?: string, contentType?: MessageContentType): void;
    /**
     * Display HttpErrorResponse, text, or object as error. For object, the display will be JSON with indent.
     * @param error
     * @param snackBar
     * @param subtitle
     */
    error(error: HttpErrorResponse | any, snackBar?: boolean, subtitle?: string): void;
    /**
     * Display HttpErrorResponse, text, or object as warn.
     * @param error
     * @param snackBar
     * @param subtitle
     */
    warn(error: HttpErrorResponse | any, snackBar?: boolean, subtitle?: string): void;
    notify(message: string, subtitle?: string, contentType?: MessageContentType): void;
    private errorOrWarning;
    /**
     * Warn message always is displayed in dialog content.
     * @param message
     * @param subtitle
     * @param contentType
     */
    warnMessage(message: string, subtitle?: string, contentType?: MessageContentType): void;
    /**
     * Error message always is displayed in dialog content.
     * @param message
     * @param subtitle
     * @param contentType
     */
    errorMessage(message: string, subtitle?: string, contentType?: MessageContentType): void;
    private getMessage;
    clear(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AlertService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AlertService>;
}
