import { InjectionToken, Type } from '@angular/core';
import { Observable } from 'rxjs';
import { ActionSheetItem } from './types';
import * as i0 from "@angular/core";
/**
 * For derived singleton services.
 */
export declare class RootInjectorGuard {
    constructor(type: Type<any>);
}
/**
 * Base type for event bus of an application event.
 * A component should inject a derived class in the constructor to receive or emit the event.
 * This class is basically a wrapper of Subject<T> of rxjs.
 * DP:
 */
export declare abstract class AnySubjectService<T> {
    private subject;
    private subjectObservable;
    constructor();
    /**
     * For subscribing the event. The component that subscribes the event should unsubscribe in ngOnDestroy.
     */
    getMessage(): Observable<T>;
    /**
     * For emitting event
     * @param e Event data to emit.
     */
    emit(e: T): void;
}
/**
 * For singleton subject service.
 */
export declare abstract class GlobalSubjectService<T> extends RootInjectorGuard {
    private subject;
    private subjectObservable;
    constructor(type: Type<any>);
    /**
     * For subscribing the event. The component that subscribes the event should unsubscribe in ngOnDestroy.
     */
    getMessage(): Observable<T>;
    /**
     * For emitting event
     * @param e Event data to emit.
     */
    emit(e: T): void;
}
/**
 * Send and receive message across modules for NotificationsService
 * This service is to be used across modules, lazy or eager. To be provided in root module.
 */
export declare class ActionSheetItemSubjectService extends GlobalSubjectService<ActionSheetItem> {
    constructor();
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionSheetItemSubjectService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ActionSheetItemSubjectService>;
}
export declare const DIALOG_ACTIONS_ALIGN: InjectionToken<"start" | "center" | "end">;
