import { AfterViewInit, ComponentFactoryResolver, OnDestroy, Type } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { DataComponentDirective } from 'nmce-directives';
import { Observable } from 'rxjs';
import { DataComponent } from '../_types/DataComponent';
import * as i0 from "@angular/core";
/**
 * This is to host another component which has implemented interfact DataComponent.
 * And another component is to be displayed in a dialog but not need to answer but to close.
 * The Close button may vary depending on the screen size.
 * This component is primarily used in DataComponentDialogService.
 * This is based on the concept in https://angular.io/guide/dynamic-component-loader
 */
export declare class DataComponentDialog implements AfterViewInit, OnDestroy {
    protected dialogData: {
        title: string;
        externalComponentType: Type<DataComponent>;
        componentData: any;
        isSmallScreen: boolean;
        fullScreen: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<DataComponentDialog>;
    protected componentFactoryResolver: ComponentFactoryResolver;
    title: string;
    data: any;
    /**
     * Reference to dataComponentHost with ng-container
     */
    componentHost: DataComponentDirective;
    externalComponentType: Type<DataComponent>;
    fullScreen: boolean;
    /**
     * True to have the Close button displayed on the top right corner.
     */
    isSmallScreen: boolean;
    constructor(dialogData: {
        title: string;
        externalComponentType: Type<DataComponent>;
        componentData: any;
        isSmallScreen: boolean;
        fullScreen: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<DataComponentDialog>, componentFactoryResolver: ComponentFactoryResolver);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    loadComponent(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataComponentDialog, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataComponentDialog, "ng-component", never, { "title": { "alias": "title"; "required": false; }; "data": { "alias": "data"; "required": false; }; }, {}, never, never, false, never>;
}
/**
 * Display an NG component in a dialog, and this dialog has not need to answer but close.
 * For a component defined in a lazy module, use LazyComponentDialogService.
 */
export declare class DataComponentDialogService {
    private dialog;
    modalRef: MatDialogRef<DataComponentDialog>;
    constructor(dialog: MatDialog);
    /**
     *
     * @param title Dialog title
     * @param externalComponentType
     * @param componentData pass data to the instance of externalComponentType
     * @param config autofocus or fullScreen
     * @returns anything
     */
    open(title: string, externalComponentType: Type<DataComponent>, componentData: any, config?: {
        autofocus?: boolean;
        fullScreen?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataComponentDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DataComponentDialogService>;
}
