import { HttpClient } from '@angular/common/http';
import { AfterViewInit, ElementRef, Renderer2 } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { SafeUrl } from '@angular/platform-browser';
import { Observable } from 'rxjs';
import { HtmlBaseDialogService } from './htmlBaseDialogService';
import { DialogSize } from './types';
import * as i0 from "@angular/core";
/**
 * Contain HTML content, used in HtmlDialogService.
 * The content is contained inside another html tag, and all href linkes will be opened in new browser tab.
 */
export declare class HtmlDialogComponent implements AfterViewInit {
    data: {
        title: string;
        htmlContent: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlDialogComponent>;
    protected renderer: Renderer2;
    title: string;
    htmlContent: string;
    useBackButton: boolean;
    constructor(data: {
        title: string;
        htmlContent: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlDialogComponent>, renderer: Renderer2);
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlDialogComponent, "html-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Contain HTML content loaded from a url, used in HtmlHReflDialogService. If there's an error during loading, the error will be displayed n the dialog body.
 */
export declare class HtmlHRefDialogComponent implements AfterViewInit {
    protected data: {
        title: string;
        url: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlHRefDialogComponent>;
    protected httpClient: HttpClient;
    protected renderer: Renderer2;
    title: string;
    /**
     * URL is passed by a service
     */
    url: string;
    useBackButton: boolean;
    htmlContent: string;
    constructor(data: {
        title: string;
        url: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlHRefDialogComponent>, httpClient: HttpClient, renderer: Renderer2);
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlHRefDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlHRefDialogComponent, "html-ref-dialog", never, {}, {}, never, never, false, never>;
}
export declare class HtmlImgDialogComponent {
    data: {
        title: string;
        imageUrl: string | SafeUrl;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlImgDialogComponent>;
    title: string;
    imageUrl: string | SafeUrl;
    useBackButton: boolean;
    private _scaleToWidth;
    /**
     * Default true. value persisted with sessionStorage.
     */
    get scaleToWidth(): boolean;
    set scaleToWidth(v: boolean);
    htmlContentElement?: ElementRef;
    constructor(data: {
        title: string;
        imageUrl: string | SafeUrl;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlImgDialogComponent>);
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlImgDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlImgDialogComponent, "html-img-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Display HTML content in a dialog.  Use this only when you are sure the HTML content does not contain naughty styling that could do graffiti all over the NG2 page.
 */
export declare class HtmlDialogService extends HtmlBaseDialogService<HtmlDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
    * Display html content in a dialog
    * @param title title of the dialog
    * @param htmlContent html content to be rendered in the dialog body
    */
    open(data: {
        title?: string;
        htmlContent?: string;
        size?: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlDialogService>;
}
/**
 * Display HTML content from URL in a dialog. Use this only when you are sure the HTML content does not contain naughty styling that could  do graffiti all over the NG2 page.
 * If the URL is under the same url root of NG2 app, make sure thee content directory is with a rewrite rule like <add input="{REQUEST_URI}" pattern="^/(content)" negate="true"/>
 * Otherwise if the file is not found, the program may treat the url as a legitimate NG2 route, because of other rewrite rules; and then various warnings or errors may be appearing
 * in browser console because of missing resources or confliciting stylings.
 * Warning: You should provide url which will not return HTML that may jeopardize the health of the Angular SPA. If you really want to show a random but not too malicious Web page inside the SPA,
 * you may use HtmlHRefFrameDialogService which will put the Web content inside a frame.
 */
export declare class HtmlHRefDialogService extends HtmlBaseDialogService<HtmlHRefDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
     * Display html from url.  If there's an error during loading, the error will be displayed n the dialog body.
     * @param title
     * @param url to be rendered in the dialog body
     */
    open(data: {
        title?: string;
        url?: string;
        size?: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlHRefDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlHRefDialogService>;
}
/**
 * Display image with option scale to fit width or original resolution.
 *
 */
export declare class HtmlImgDialogService extends HtmlBaseDialogService<HtmlImgDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
    * Display html content in a dialog
    * @param title title of the dialog
    * @param imageUrl html content to be rendered in the dialog body
    */
    open(data: {
        title?: string;
        imageUrl?: string | SafeUrl;
        size?: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlImgDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlImgDialogService>;
}
