import { HttpClient } from '@angular/common/http';
import { AfterViewInit, ElementRef, Renderer2 } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { Observable } from 'rxjs';
import { HtmlBaseDialogService } from './htmlBaseDialogService';
import { DialogSize } from './types';
import * as i0 from "@angular/core";
/**
 * Contain HTML content in iframe, used in HtmlFrameDialogService.
 */
export declare class HtmlFrameDialogComponent implements AfterViewInit {
    data: {
        title: string;
        htmlContent: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlFrameDialogComponent>;
    title: string;
    htmlContent: string;
    useBackButton: boolean;
    constructor(data: {
        title: string;
        htmlContent: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlFrameDialogComponent>);
    /**
     * iframe element to hold the HTML content
     */
    htmlContentElement?: ElementRef;
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlFrameDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlFrameDialogComponent, "html-frame-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Contain HTML content loaded from a url, used in HtmlHReflDialogService. If there's an error during loading, the error will be displayed inn the dialog body.
 */
export declare class HtmlHRefFrameDialogComponent implements AfterViewInit {
    data: {
        title: string;
        url: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlHRefFrameDialogComponent>;
    protected httpClient: HttpClient;
    protected renderer: Renderer2;
    title: string;
    /**
     * URL is passed by a service
     */
    url: string;
    useBackButton: boolean;
    /**
     * Constructor
     * @param data If useBackButton=true, the dialog will be 98% width and height of the viewport.
     * @param dialogRef
     * @param httpClient
     */
    constructor(data: {
        title: string;
        url: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlHRefFrameDialogComponent>, httpClient: HttpClient, renderer: Renderer2);
    /**
     * HTML placeholder
     */
    htmlContentElement?: ElementRef;
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlHRefFrameDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlHRefFrameDialogComponent, "html-href-frame-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Display HTML content in the iframe of the dialog.
 */
export declare class HtmlFrameDialogService extends HtmlBaseDialogService<HtmlFrameDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
    * Display html content in a dialog
    * @param title title of the dialog
    * @param htmlContent html content to be rendered in the dialog body
    */
    open(data: {
        title?: string;
        htmlContent?: string;
        size?: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlFrameDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlFrameDialogService>;
}
/**
 * Display HTML content from URL in the iframe of the dialog.
 * If the URL is under the same url root of NG2 app, make sure thee content directory is with a rewrite rule like <add input="{REQUEST_URI}" pattern="^/(content)" negate="true"/>
 * Otherwise if the file is not found, the program may treat the url as a legitimate NG2 route, because of other rewrite rules.
 */
export declare class HtmlHRefFrameDialogService extends HtmlBaseDialogService<HtmlHRefFrameDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
     * Display html from url.  If there's an error during loading, the error will be displayed n the dialog body.
     * @param title
     * @param url to be rendered in the dialog body
     */
    open(data: {
        title?: string;
        url?: string;
        size?: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlHRefFrameDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlHRefFrameDialogService>;
}
