import { HttpClient } from '@angular/common/http';
import { AfterViewInit, ElementRef } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { Observable } from 'rxjs';
import { DialogSize } from '../_ui_services/types';
import * as i0 from "@angular/core";
/**
 * Contain HTML content, used in TextDialogService.
 */
export declare class TextDialogComponent implements AfterViewInit {
    data: {
        title: string;
        lines: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<TextDialogComponent>;
    title: string;
    lines: string;
    useBackButton: boolean;
    constructor(data: {
        title: string;
        lines: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<TextDialogComponent>);
    htmlContentElement: ElementRef;
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TextDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TextDialogComponent, "text-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Display text as HTML pre in a dialog, which is loaded from a url, used in TextHReflDialogService. If there's an error during loading, the error will be displayed n the dialog body.
 */
export declare class TextHRefDialogComponent implements AfterViewInit {
    actionsAlign: string;
    dialogRef: MatDialogRef<TextDialogComponent>;
    private httpClient;
    title: string;
    /**
     * URL is passed by a service
     */
    url: string;
    useBackButton: boolean;
    constructor(data: {
        title: string;
        url: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<TextDialogComponent>, httpClient: HttpClient);
    /**
     * HTML placeholder
     */
    htmlContentElement?: ElementRef;
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TextHRefDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TextHRefDialogComponent, "text-href-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Display text as HTML pre in a dialog
 */
export declare class TextDialogService {
    private dialog;
    constructor(dialog: MatDialog);
    modalRef?: MatDialogRef<TextDialogComponent>;
    /**
    * Display html content in a dialog
    * @param title title of the dialog
    * @param lines html content to be rendered in the dialog body
    */
    open(data: {
        title?: string;
        lines?: string;
        size?: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TextDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TextDialogService>;
}
/**
 * Display HTML content from URL in a dialog.
 * If the URL is under the same url root of NG2 app, make sure thee content directory is with a rewrite rule like <add input="{REQUEST_URI}" pattern="^/(content)" negate="true"/>
 * Otherwise if the file is not found, the program may treat the url as a legitimate NG2 route, because of other rewrite rules.
 */
export declare class TextHReflDialogService {
    private dialog;
    constructor(dialog: MatDialog);
    modalRef?: MatDialogRef<TextHRefDialogComponent>;
    /**
     * Display html from url.  If there's an error during loading, the error will be displayed n the dialog body.
     * @param title
     * @param url to be rendered in the dialog body
     */
    open(data: {
        title?: string;
        url?: string;
        size?: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TextHReflDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TextHReflDialogService>;
}
