import { Type } from '@angular/core';
import { Router } from '@angular/router';
import { Observable } from 'rxjs';
import { RootInjectorGuard } from './baseTypes';
import * as i0 from "@angular/core";
/**
 * Waiting for progress, showing spinner
 */
export declare abstract class WaitServiceBase extends RootInjectorGuard {
    private subject;
    private keepAfterNavigationChange;
    /**
     * Client code may use this to disable the button that triggered the action
     */
    loading: boolean;
    constructor(router: Router, type: Type<any>);
    setWait(w: WaitMessage): void;
    getMessage(): Observable<WaitMessage>;
}
/**
 * Used togehter with <wait> element, generally for handling observable. Start wait before calling an observable, stop wait in subscribe.
 * The mechanism is sending and receiving WaitMessage.
 */
export declare class WaitService extends WaitServiceBase {
    constructor(router: Router);
    static ɵfac: i0.ɵɵFactoryDeclaration<WaitService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<WaitService>;
}
/**
 * This service is intentionally not injectable, and should be created inside the constructor of a component.
 */
export declare class LocalWaitService {
    private waitService;
    loading: boolean;
    constructor(waitService: WaitService);
    StartWait(): void;
    EndWait(): void;
}
export declare class WaitProgressService extends WaitServiceBase {
    constructor(router: Router);
    static ɵfac: i0.ɵɵFactoryDeclaration<WaitProgressService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<WaitProgressService>;
}
export interface WaitMessage {
    text?: string;
    value?: number;
    loading: boolean;
    mode?: 'determinate' | 'indeterminate' | 'buffer' | 'query';
}
