import { Location } from '@angular/common';
import { HttpClient } from '@angular/common/http';
import { Renderer2 } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { Observable } from 'rxjs';
import { HtmlBaseDialogService } from '../_ui_services/htmlBaseDialogService';
import { HtmlFrameDialogComponent, HtmlHRefFrameDialogComponent } from '../_ui_services/htmlFrameDialog.component';
import { DialogSize } from '../_ui_services/types';
import * as i0 from "@angular/core";
/**
 * Contain HTML content in iframe, used in HtmlFrameDialogService.
 */
export declare class HtmlFramePrintDialogComponent extends HtmlFrameDialogComponent {
    data: {
        title: string;
        htmlContent: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlFrameDialogComponent>;
    private location;
    constructor(data: {
        title: string;
        htmlContent: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlFrameDialogComponent>, location: Location);
    print(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlFramePrintDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlFramePrintDialogComponent, "html-frame-print-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Contain HTML content loaded from a url, used in HtmlHReflDialogService. If there's an error during loading, the error will be displayed inn the dialog body.
 */
export declare class HtmlHRefFramePrintDialogComponent extends HtmlHRefFrameDialogComponent {
    data: {
        title: string;
        url: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlHRefFrameDialogComponent>;
    protected httpClient: HttpClient;
    private location;
    protected renderer: Renderer2;
    /**
     * Constructor
     * @param data If useBackButton=true, the dialog will be 98% width and height of the viewport.
     * @param dialogRef
     * @param httpClient
     */
    constructor(data: {
        title: string;
        url: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlHRefFrameDialogComponent>, httpClient: HttpClient, location: Location, renderer: Renderer2);
    print(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlHRefFramePrintDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlHRefFramePrintDialogComponent, "html-href-frame-print-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Display HTML content in the iframe of the dialog.
 */
export declare class HtmlFramePrintDialogService extends HtmlBaseDialogService<HtmlFramePrintDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
    * Display html content in a dialog
    * @param title title of the dialog
    * @param htmlContent html content to be rendered in the dialog body
    */
    open(data: {
        title: string;
        htmlContent: string;
        size: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlFramePrintDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlFramePrintDialogService>;
}
/**
 * Display HTML content from URL in the iframe of the dialog.
 * If the URL is under the same url root of NG2 app, make sure thee content directory is with a rewrite rule like <add input="{REQUEST_URI}" pattern="^/(content)" negate="true"/>
 * Otherwise if the file is not found, the program may treat the url as a legitimate NG2 route, because of other rewrite rules.
 */
export declare class HtmlHRefFramePrintDialogService extends HtmlBaseDialogService<HtmlHRefFramePrintDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
     * Display html from url.  If there's an error during loading, the error will be displayed n the dialog body.
     * @param title
     * @param url to be rendered in the dialog body
     */
    open(data: {
        title: string;
        url: string;
        size: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlHRefFramePrintDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlHRefFramePrintDialogService>;
}
