import { Location } from '@angular/common';
import { HttpClient } from '@angular/common/http';
import { Renderer2 } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { SafeUrl } from '@angular/platform-browser';
import { Observable } from 'rxjs';
import { HtmlBaseDialogService } from '../_ui_services/htmlBaseDialogService';
import { HtmlDialogComponent, HtmlHRefDialogComponent, HtmlImgDialogComponent } from '../_ui_services/htmlDialog.component';
import { DialogSize } from '../_ui_services/types';
import * as i0 from "@angular/core";
/**
 * Contain HTML content, used in HtmlDialogService.
 */
export declare class HtmlPrintDialogComponent extends HtmlDialogComponent {
    data: {
        title: string;
        htmlContent: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlDialogComponent>;
    private location;
    private cssUrl;
    protected renderer: Renderer2;
    constructor(data: {
        title: string;
        htmlContent: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlDialogComponent>, location: Location, cssUrl: string, renderer: Renderer2);
    print(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlPrintDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlPrintDialogComponent, "html-print-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Contain HTML content loaded from a url, used in HtmlHReflDialogService. If there's an error during loading, the error will be displayed inn the dialog body.
 */
export declare class HtmlHRefPrintDialogComponent extends HtmlHRefDialogComponent {
    data: {
        title: string;
        url: string;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlHRefDialogComponent>;
    protected httpClient: HttpClient;
    private location;
    protected renderer: Renderer2;
    /**
     * Constructor
     * @param data If useBackButton=true, the dialog will be 98% width and height of the viewport.
     * @param dialogRef
     * @param httpClient
     */
    constructor(data: {
        title: string;
        url: string;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlHRefDialogComponent>, httpClient: HttpClient, location: Location, renderer: Renderer2);
    print(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlHRefPrintDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlHRefPrintDialogComponent, "html-href-print-dialog", never, {}, {}, never, never, false, never>;
}
export declare class HtmlImgPrintDialogComponent extends HtmlImgDialogComponent {
    data: {
        title: string;
        imageUrl: string | SafeUrl;
        useBackButton: boolean;
    };
    actionsAlign: string;
    dialogRef: MatDialogRef<HtmlImgDialogComponent>;
    private location;
    private cssUrl;
    constructor(data: {
        title: string;
        imageUrl: string | SafeUrl;
        useBackButton: boolean;
    }, actionsAlign: string, dialogRef: MatDialogRef<HtmlImgDialogComponent>, location: Location, cssUrl: string);
    print(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlImgPrintDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HtmlImgPrintDialogComponent, "html-img-print-dialog", never, {}, {}, never, never, false, never>;
}
/**
 * Display HTML content in the dialog.
 */
export declare class HtmlPrintDialogService extends HtmlBaseDialogService<HtmlPrintDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
    * Display html content in a dialog
    * @param title title of the dialog
    * @param htmlContent html content to be rendered in the dialog body
    */
    open(data: {
        title: string;
        htmlContent: string;
        size: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlPrintDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlPrintDialogService>;
}
/**
 * Display HTML content from URL in the dialog.
 * If the URL is under the same url root of NG2 app, make sure thee content directory is with a rewrite rule like <add input="{REQUEST_URI}" pattern="^/(content)" negate="true"/>
 * Otherwise if the file is not found, the program may treat the url as a legitimate NG2 route, because of other rewrite rules.
 */
export declare class HtmlHRefPrintDialogService extends HtmlBaseDialogService<HtmlHRefPrintDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
     * Display html from url.  If there's an error during loading, the error will be displayed n the dialog body.
     * @param title
     * @param url to be rendered in the dialog body
     */
    open(data: {
        title: string;
        url: string;
        size: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlHRefPrintDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlHRefPrintDialogService>;
}
export declare class HtmlImgPrintDialogService extends HtmlBaseDialogService<HtmlImgPrintDialogComponent> {
    protected dialog: MatDialog;
    constructor(dialog: MatDialog);
    /**
    * Display html content in a dialog
    * @param title title of the dialog
    * @param htmlContent html content to be rendered in the dialog body
    */
    open(data: {
        title: string;
        imageUrl: string | SafeUrl;
        size: DialogSize;
        useBackButton?: boolean;
    }): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<HtmlImgPrintDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HtmlImgPrintDialogService>;
}
